==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/search/all_75.js <==
var searchData=
[
  ['u_5fchar',['U_CHAR',['../pdf_8h.html#afa7a66dcd6e9cb1385f1b0508545b40a',1,'pdf.h']]],
  ['u_5fint',['U_INT',['../pdf_8h.html#a7a0f57e64d35a09cc33d3c32d2b0d982',1,'pdf.h']]],
  ['u_5flong',['U_LONG',['../pdf_8h.html#a4dce060e264ba01155a02c1f75540285',1,'pdf.h']]],
  ['u_5fshort',['U_SHORT',['../pdf_8h.html#a6d72945d8d77c9fd10f6d1d0bba7eb6a',1,'pdf.h']]],
  ['ucs4_5fto_5fpango_5fmarkup_5fformat',['ucs4_to_pango_markup_format',['../cairo_8c.html#ad369403615267df8feb966a5c5b2d361',1,'cairo.c']]],
  ['ucs4_5fto_5futf8',['ucs4_to_utf8',['../plcore_8c.html#aa6086478e2def7762450396bc71bc316',1,'ucs4_to_utf8(PLUNICODE unichar, char *ptr):&#160;plcore.c'],['../plplotP_8h.html#a2f6d100c298c3699996281a98f0e019f',1,'ucs4_to_utf8(PLUNICODE unichar, char *ptr):&#160;plcore.c']]],
  ['uline',['uline',['../structPLCairo.html#a9fc98c50143c2b0df5c850e58800a4ef',1,'PLCairo']]],
  ['umx',['umx',['../structPLStream.html#abe2d9205f9174884d74a322c6cc78fe7',1,'PLStream']]],
  ['umy',['umy',['../structPLStream.html#afd954dba26f50f0e747c8b6d8daf193f',1,'PLStream']]],
  ['undef',['UNDEF',['../plshade_8c.html#abde25a67f4046530ae1c572cefeb5869',1,'plshade.c']]],
  ['underlined',['underlined',['../classwxPLDevBase.html#a0d1576bedd2aaaba8ab3674cb4f64682',1,'wxPLDevBase::underlined()'],['../classQtPLDriver.html#ac3ba463b209a5b7664c1fadc964b7641',1,'QtPLDriver::underlined()']]],
  ['unicode',['Unicode',['../structHershey__to__Unicode__table.html#a63927014341b3ba1eec039c34b7cfcb6',1,'Hershey_to_Unicode_table::Unicode()'],['../structUnicode__to__Type1__table.html#afc981b330d66e7885e6452356674822a',1,'Unicode_to_Type1_table::Unicode()']]],
  ['unicode_5farray',['unicode_array',['../structEscText.html#ac5ed6a599aa6688ea4e016d5cf9184d7',1,'EscText']]],
  ['unicode_5farray_5flen',['unicode_array_len',['../structEscText.html#a0226f7ca906eec56ae4068ba37a8542b',1,'EscText']]],
  ['unicode_5fbuffer',['unicode_buffer',['../plcore_8c.html#abc490f7a97e538ac7fa480678647fbfd',1,'plcore.c']]],
  ['unicode_5fchar',['unicode_char',['../structEscText.html#ac56ff5804691c224408db9af7c99ecc0',1,'EscText']]],
  ['unicode_5fto_5fdingbats_5flookup_5ftable',['unicode_to_dingbats_lookup_table',['../plunicode-type1_8h.html#a674af18dbdc988c6def70b72f208d90b',1,'plunicode-type1.h']]],
  ['unicode_5fto_5fstandard_5flookup_5ftable',['unicode_to_standard_lookup_table',['../plunicode-type1_8h.html#ade7c8b0082f182f1b4f4cd0c12fab4b9',1,'plunicode-type1.h']]],
  ['unicode_5fto_5fsymbol_5flookup_5ftable',['unicode_to_symbol_lookup_table',['../plunicode-type1_8h.html#a158045056cf63af57aaebb2808629206',1,'plunicode-type1.h']]],
  ['unicode_5fto_5ftype1_5ftable',['Unicode_to_Type1_table',['../structUnicode__to__Type1__table.html',1,'']]],
  ['update',['Update',['../classwxPLplotstream.html#aee598cbbdb415be0198a6021a4c19488',1,'wxPLplotstream']]],
  ['update_5fh_5fscrollbar',['UPDATE_H_SCROLLBAR',['../plframe_8c.html#a48873796dd91962eb99410db39704c29',1,'UPDATE_H_SCROLLBAR():&#160;plframe.c'],['../plplotter_8c.html#a48873796dd91962eb99410db39704c29',1,'UPDATE_H_SCROLLBAR():&#160;plplotter.c']]],
  ['update_5forient',['update_orient',['../namespacePlframe.html#a10201fdc6d0c45453434f63f6f7c5701',1,'Plframe']]],
  ['update_5fv_5fscrollbar',['UPDATE_V_SCROLLBAR',['../plframe_8c.html#a657b634edd312e28641b0bd2be047f85',1,'UPDATE_V_SCROLLBAR():&#160;plframe.c'],['../plplotter_8c.html#a657b634edd312e28641b0bd2be047f85',1,'UPDATE_V_SCROLLBAR():&#160;plplotter.c']]],
  ['update_5fzoom',['update_zoom',['../namespacePlframe.html#a9b260e4a06de2cda8fb1d880d78f9542',1,'Plframe']]],
  ['updatecmd',['updatecmd',['../structTkDev.html#a5392c715a876c5d53e17e3a2f468e443',1,'TkDev']]],
  ['updatehscrollbar',['UpdateHScrollbar',['../plframe_8c.html#a55f386dac5b0d5cb85296bd7e196fd98',1,'UpdateHScrollbar(register PlFrame *):&#160;plframe.c'],['../plplotter_8c.html#a6e8ad480c90e90ae68cd8b2a9ff41566',1,'UpdateHScrollbar(register PlPlotter *):&#160;plplotter.c']]],
  ['updaterband',['UpdateRband',['../plframe_8c.html#a65c198c726fdbf1a24079428c4c13cdf',1,'UpdateRband(PlFrame *):&#160;plframe.c'],['../plplotter_8c.html#aa56fac65af13b1969e30b97e2f1a818a',1,'UpdateRband(PlPlotter *):&#160;plplotter.c']]],
  ['updatevscrollbar',['UpdateVScrollbar',['../plframe_8c.html#abebd7ec681497127fc6ea9ce684d65f8',1,'UpdateVScrollbar(register PlFrame *):&#160;plframe.c'],['../plplotter_8c.html#ab984998650b811adfb081cf05e914951',1,'UpdateVScrollbar(register PlPlotter *):&#160;plplotter.c']]],
  ['updatexhairs',['UpdateXhairs',['../plframe_8c.html#a22cc101003776d82d7cfe4fee8094e89',1,'UpdateXhairs(PlFrame *):&#160;plframe.c'],['../plplotter_8c.html#a055aadf264e44a8eed4eb13f4c7e0973',1,'UpdateXhairs(PlPlotter *):&#160;plplotter.c']]],
  ['updown',['upDown',['../structPLCairo.html#acc53ff3dfd75bceb46c5647814f127d0',1,'PLCairo']]],
  ['upper_5fmask',['UPPER_MASK',['../mt19937ar_8c.html#a39bc458849360f8f371b54c4365d397f',1,'mt19937ar.c']]],
  ['urx',['urx',['../structPSDev.html#aa759c208dcaeaebf15e491a48e20de99',1,'PSDev']]],
  ['ury',['ury',['../structPSDev.html#a2a413bbcb369b38931eb0b95f64f5add',1,'PSDev']]],
  ['usage',['usage',['../plargs_8c.html#aef1bd6ad890a110b466cb0e8088507a2',1,'plargs.c']]],
  ['use',['Use',['../wxwidgets_8h.html#acd74d9b9b8ef45e8ef2651b5074d4ae8',1,'wxwidgets.h']]],
  ['use_5fpersistence',['use_persistence',['../structGcwPLdev.html#a052ed9a591cc873502ca81e0b6ffb577',1,'GcwPLdev']]],
  ['use_5fpixmap',['use_pixmap',['../structGcwPLdev.html#a27fa6673edb596962c49dde8839d8bf5',1,'GcwPLdev']]],
  ['use_5fqhull',['USE_QHULL',['../delaunay_8c.html#a71d612363a241c0f6fca4e05ad5ac0cb',1,'delaunay.c']]],
  ['user',['user',['../structPLStream.html#a2c45ef41fca4c2716c99b911c9c8d671',1,'PLStream']]],
  ['user_5fmouse',['user_mouse',['../namespacePlframe.html#a891edbf6e3b2ec98f75c8fbcbbfde5e2',1,'Plframe']]],
  ['usingpldll',['USINGPLDLL',['../pltcl_8c.html#a9270d52a021fe2bc15b09224172ad651',1,'pltcl.c']]],
  ['utf8_5fto_5fucs4',['utf8_to_ucs4',['../plcore_8c.html#a09b8b47af09160143a9e7244f79f03b9',1,'utf8_to_ucs4(const char *ptr, PLUNICODE *unichar):&#160;plcore.c'],['../plcore_8h.html#a09b8b47af09160143a9e7244f79f03b9',1,'utf8_to_ucs4(const char *ptr, PLUNICODE *unichar):&#160;plcore.h']]],
  ['utmp',['utmp',['../plot3d_8c.html#a7e3aab59224e9c6116d2c8cc2243fac1',1,'plot3d.c']]]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/search/all_75.js <==
var searchData=
[
  ['u_5fchar',['U_CHAR',['../pdf_8h.html#afa7a66dcd6e9cb1385f1b0508545b40a',1,'pdf.h']]],
  ['u_5fint',['U_INT',['../pdf_8h.html#a7a0f57e64d35a09cc33d3c32d2b0d982',1,'pdf.h']]],
  ['u_5flong',['U_LONG',['../pdf_8h.html#a4dce060e264ba01155a02c1f75540285',1,'pdf.h']]],
  ['u_5fshort',['U_SHORT',['../pdf_8h.html#a6d72945d8d77c9fd10f6d1d0bba7eb6a',1,'pdf.h']]],
  ['ucs4_5fto_5fpango_5fmarkup_5fformat',['ucs4_to_pango_markup_format',['../cairo_8c.html#ad369403615267df8feb966a5c5b2d361',1,'cairo.c']]],
  ['ucs4_5fto_5futf8',['ucs4_to_utf8',['../plcore_8c.html#aa6086478e2def7762450396bc71bc316',1,'ucs4_to_utf8(PLUNICODE unichar, char *ptr):&#160;plcore.c'],['../plplotP_8h.html#a2f6d100c298c3699996281a98f0e019f',1,'ucs4_to_utf8(PLUNICODE unichar, char *ptr):&#160;plcore.c']]],
  ['uline',['uline',['../structPLCairo.html#a9fc98c50143c2b0df5c850e58800a4ef',1,'PLCairo']]],
  ['umx',['umx',['../structPLStream.html#abe2d9205f9174884d74a322c6cc78fe7',1,'PLStream']]],
  ['umy',['umy',['../structPLStream.html#afd954dba26f50f0e747c8b6d8daf193f',1,'PLStream']]],
  ['undef',['UNDEF',['../plshade_8c.html#abde25a67f4046530ae1c572cefeb5869',1,'plshade.c']]],
  ['underlined',['underlined',['../structTextSizeInfo.html#acf6aa71074a2c3e32d0b286c0b24b9c6',1,'TextSizeInfo::underlined()'],['../classQtPLDriver.html#ac3ba463b209a5b7664c1fadc964b7641',1,'QtPLDriver::underlined()']]],
  ['unicode',['Unicode',['../structHershey__to__Unicode__table.html#a63927014341b3ba1eec039c34b7cfcb6',1,'Hershey_to_Unicode_table::Unicode()'],['../structUnicode__to__Type1__table.html#afc981b330d66e7885e6452356674822a',1,'Unicode_to_Type1_table::Unicode()']]],
  ['unicode_5farray',['unicode_array',['../structEscText.html#ac5ed6a599aa6688ea4e016d5cf9184d7',1,'EscText']]],
  ['unicode_5farray_5flen',['unicode_array_len',['../structEscText.html#a0226f7ca906eec56ae4068ba37a8542b',1,'EscText']]],
  ['unicode_5fbuffer_5fstatic',['unicode_buffer_static',['../plcore_8c.html#ae30c62e1206957286d289d92feddb783',1,'plcore.c']]],
  ['unicode_5fchar',['unicode_char',['../structEscText.html#ac56ff5804691c224408db9af7c99ecc0',1,'EscText']]],
  ['unicode_5fto_5fdingbats_5flookup_5ftable',['unicode_to_dingbats_lookup_table',['../plunicode-type1_8h.html#a674af18dbdc988c6def70b72f208d90b',1,'plunicode-type1.h']]],
  ['unicode_5fto_5fstandard_5flookup_5ftable',['unicode_to_standard_lookup_table',['../plunicode-type1_8h.html#ade7c8b0082f182f1b4f4cd0c12fab4b9',1,'plunicode-type1.h']]],
  ['unicode_5fto_5fsymbol_5flookup_5ftable',['unicode_to_symbol_lookup_table',['../plunicode-type1_8h.html#a158045056cf63af57aaebb2808629206',1,'plunicode-type1.h']]],
  ['unicode_5fto_5ftype1_5ftable',['Unicode_to_Type1_table',['../structUnicode__to__Type1__table.html',1,'']]],
  ['update_5fh_5fscrollbar',['UPDATE_H_SCROLLBAR',['../plframe_8c.html#a48873796dd91962eb99410db39704c29',1,'UPDATE_H_SCROLLBAR():&#160;plframe.c'],['../plplotter_8c.html#a48873796dd91962eb99410db39704c29',1,'UPDATE_H_SCROLLBAR():&#160;plplotter.c']]],
  ['update_5forient',['update_orient',['../namespacePlframe.html#a10201fdc6d0c45453434f63f6f7c5701',1,'Plframe']]],
  ['update_5fv_5fscrollbar',['UPDATE_V_SCROLLBAR',['../plframe_8c.html#a657b634edd312e28641b0bd2be047f85',1,'UPDATE_V_SCROLLBAR():&#160;plframe.c'],['../plplotter_8c.html#a657b634edd312e28641b0bd2be047f85',1,'UPDATE_V_SCROLLBAR():&#160;plplotter.c']]],
  ['update_5fzoom',['update_zoom',['../namespacePlframe.html#a9b260e4a06de2cda8fb1d880d78f9542',1,'Plframe']]],
  ['updatecmd',['updatecmd',['../structTkDev.html#a5392c715a876c5d53e17e3a2f468e443',1,'TkDev']]],
  ['updatehscrollbar',['UpdateHScrollbar',['../plframe_8c.html#a55f386dac5b0d5cb85296bd7e196fd98',1,'UpdateHScrollbar(register PlFrame *):&#160;plframe.c'],['../plplotter_8c.html#a6e8ad480c90e90ae68cd8b2a9ff41566',1,'UpdateHScrollbar(register PlPlotter *):&#160;plplotter.c']]],
  ['updaterband',['UpdateRband',['../plframe_8c.html#a65c198c726fdbf1a24079428c4c13cdf',1,'UpdateRband(PlFrame *):&#160;plframe.c'],['../plplotter_8c.html#aa56fac65af13b1969e30b97e2f1a818a',1,'UpdateRband(PlPlotter *):&#160;plplotter.c']]],
  ['updatevscrollbar',['UpdateVScrollbar',['../plframe_8c.html#abebd7ec681497127fc6ea9ce684d65f8',1,'UpdateVScrollbar(register PlFrame *):&#160;plframe.c'],['../plplotter_8c.html#ab984998650b811adfb081cf05e914951',1,'UpdateVScrollbar(register PlPlotter *):&#160;plplotter.c']]],
  ['updatexhairs',['UpdateXhairs',['../plframe_8c.html#a22cc101003776d82d7cfe4fee8094e89',1,'UpdateXhairs(PlFrame *):&#160;plframe.c'],['../plplotter_8c.html#a055aadf264e44a8eed4eb13f4c7e0973',1,'UpdateXhairs(PlPlotter *):&#160;plplotter.c']]],
  ['updown',['upDown',['../structPLCairo.html#acc53ff3dfd75bceb46c5647814f127d0',1,'PLCairo']]],
  ['upper_5fmask',['UPPER_MASK',['../mt19937ar_8c.html#a39bc458849360f8f371b54c4365d397f',1,'mt19937ar.c']]],
  ['urx',['urx',['../structPSDev.html#aa759c208dcaeaebf15e491a48e20de99',1,'PSDev']]],
  ['ury',['ury',['../structPSDev.html#a2a413bbcb369b38931eb0b95f64f5add',1,'PSDev']]],
  ['usage',['usage',['../plargs_8c.html#aef1bd6ad890a110b466cb0e8088507a2',1,'plargs.c']]],
  ['use_5fqhull',['USE_QHULL',['../delaunay_8c.html#a71d612363a241c0f6fca4e05ad5ac0cb',1,'delaunay.c']]],
  ['user',['user',['../structPLStream.html#a2c45ef41fca4c2716c99b911c9c8d671',1,'PLStream']]],
  ['user_5fmouse',['user_mouse',['../namespacePlframe.html#a891edbf6e3b2ec98f75c8fbcbbfde5e2',1,'Plframe']]],
  ['utf8_5fto_5fucs4',['utf8_to_ucs4',['../plcore_8c.html#a09b8b47af09160143a9e7244f79f03b9',1,'utf8_to_ucs4(const char *ptr, PLUNICODE *unichar):&#160;plcore.c'],['../plcore_8h.html#a09b8b47af09160143a9e7244f79f03b9',1,'utf8_to_ucs4(const char *ptr, PLUNICODE *unichar):&#160;plcore.h']]],
  ['utmp',['utmp',['../plot3d_8c.html#a7e3aab59224e9c6116d2c8cc2243fac1',1,'plot3d.c']]]
];
